@@ -46,6 +46,7 @@ class BaseModelListSerializer(ModelSerializer):
     tags = serializers.SerializerMethodField()
     bookmark_count = serializers.SerializerMethodField()
     sort = serializers.SerializerMethodField()
+    resourcetype = serializers.SerializerMethodField()
 
     # qa_count_string = serializers.SerializerMethodField()
 
@@ -75,6 +76,7 @@ class BaseModelListSerializer(ModelSerializer):
             'visit_count_string',
             'bookmark_count',
             'bookmark_count_string',
+            'resourcetype',
         ]
 
         read_only_fields = [
@@ -94,7 +96,8 @@ class BaseModelListSerializer(ModelSerializer):
             'visit_count',
             'visit_count_string',
             'bookmark_count',
-            'bookmark_count_string'
+            'bookmark_count_string',
+            'resourcetype',
         ]
 
     def get_url(self, obj):
@@ -146,6 +149,9 @@ class BaseModelListSerializer(ModelSerializer):
     def get_bookmark_count(self, obj):
         return obj.bookmark_count
 
+    def get_resourcetype(self, obj):
+        return obj._meta.object_name
+
 
 # Base Model Details
 class BaseModelDetailSerializer(BaseModelListSerializer):
