@@ -25,7 +25,7 @@ class ChatSessionListAPIView(ListAPIView):
 
     def get_queryset(self):
         user = self.request.user
-        queryset = ChatSession.objects.user_session(user=user).order_by('message_created_at')
+        queryset = ChatSession.objects.user_session(user=user).order_by('-message_created_at')
         return queryset
 
 
