@@ -1,3 +1,4 @@
+from django.db.models import Q
 from rest_framework.permissions import ( AllowAny, IsAuthenticated )
 from rest_framework.generics import ListAPIView
 
@@ -11,4 +12,11 @@ class SubscriptionListAPIView(ListAPIView):
     # filter_backends = (filters.SearchFilter,)
 
     def get_queryset(self, *args, **kwargs):
+        if 'product_id' in self.request.query_params:
+            product_id = self.request.query_params['product_id']
+            return Subscription.objects.active().filter(
+                Q(products__in=[product_id]) |
+                Q(type=Subscription.TYPE_ALL
+                  )
+            ).distinct()
         return Subscription.objects.active()
